@@ -1,11 +1,10 @@
 package Starch;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
-use Starch::Factory;
 use Moo::Object qw();
+use Starch::Factory;
 
+use strictures 2;
 use namespace::clean;
 
 sub new {
@@ -26,6 +25,8 @@ sub new {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Starch - A framework independent HTTP session library.
@@ -471,13 +472,6 @@ Starch GitHub issue tracker:
 
 L<https://github.com/bluefeet/Starch/issues>
 
-=head1 AUTHORS
-
-    Aran Clary Deltac <bluefeet@gmail.com>
-    Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
-    Jonathan Scott Duff <duff@pobox.com>
-    Ismail Kerim <ismail.kerim@assurant.com>
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to L<ZipRecruiter|https://www.ziprecruiter.com/>
@@ -485,10 +479,29 @@ for encouraging their employees to contribute back to the open
 source ecosystem.  Without their dedication to quality software
 development this distribution would not exist.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+    Aran Clary Deltac <bluefeet@gmail.com>
+    Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
+    Jonathan Scott Duff <duff@pobox.com>
+    Ismail Kerim <ismail.kerim@assurant.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2015 Aran Clary Deltac
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
