@@ -1,7 +1,7 @@
 package Starch::Plugin::Bundle;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -34,11 +34,12 @@ See L<Starch::Extending/PLUGINS> for more information.
 
 =cut
 
-use Types::Standard -types;
-use Types::Common::String -types;
 use Starch::Util qw( load_prefixed_module );
+use Types::Common::String -types;
+use Types::Standard -types;
 
 use Moo::Role;
+use strictures 2;
 use namespace::clean;
 
 requires( 'bundled_plugins' );
@@ -200,9 +201,9 @@ See L<Starch/SUPPORT>.
 
 See L<Starch/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-See L<Starch/LICENSE>.
+See L<Starch/COPYRIGHT AND LICENSE>.
 
 =cut
 
