@@ -1,18 +1,15 @@
 package Starch::Plugin::CookieArgs::Manager;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
-use Types::Standard -types;
-use Types::Common::String -types;
 use Types::Common::Numeric -types;
+use Types::Common::String -types;
+use Types::Standard -types;
 
 use Moo::Role;
+use strictures 2;
 use namespace::clean;
 
-with qw(
-    Starch::Plugin::ForManager
-);
+with 'Starch::Plugin::ForManager';
 
 has cookie_name => (
     is      => 'ro',
