@@ -1,7 +1,7 @@
 package Starch::Plugin::ThrottleStore;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -34,15 +34,14 @@ a log message stating which state key is being throttled.
 
 =cut
 
-use Types::Common::Numeric -types;
 use Try::Tiny;
+use Types::Common::Numeric -types;
 
 use Moo::Role;
+use strictures 2;
 use namespace::clean;
 
-with qw(
-    Starch::Plugin::ForStore
-);
+with 'Starch::Plugin::ForStore';
 
 =head1 OPTIONAL STORE ARGUMENTS
 
@@ -173,9 +172,9 @@ See L<Starch/SUPPORT>.
 
 See L<Starch/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-See L<Starch/LICENSE>.
+See L<Starch/COPYRIGHT AND LICENSE>.
 
 =cut
 
