@@ -1,7 +1,7 @@
 package Starch::Store::Layered;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -52,15 +52,14 @@ stores within layered stores.
 
 =cut
 
-use Types::Standard -types;
 use Scalar::Util qw( blessed );
+use Types::Standard -types;
 
 use Moo;
+use strictures 2;
 use namespace::clean;
 
-with qw(
-    Starch::Store
-);
+with 'Starch::Store';
 
 after BUILD => sub{
     my ($self) = @_;
@@ -228,9 +227,9 @@ See L<Starch/SUPPORT>.
 
 See L<Starch/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-See L<Starch/LICENSE>.
+See L<Starch/COPYRIGHT AND LICENSE>.
 
 =cut
 
