@@ -1,7 +1,7 @@
 package Starch::Store::Memory;
-use 5.008001;
-use strictures 2;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -15,15 +15,14 @@ tests against.
 
 =cut
 
-use Types::Standard -types;
 use Types::Common::Numeric -types;
+use Types::Standard -types;
 
 use Moo;
+use strictures 2;
 use namespace::clean;
 
-with qw(
-    Starch::Store
-);
+with 'Starch::Store';
 
 =head1 OPTIONAL ARGUMENTS
 
@@ -111,9 +110,9 @@ See L<Starch/SUPPORT>.
 
 See L<Starch/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-See L<Starch/LICENSE>.
+See L<Starch/COPYRIGHT AND LICENSE>.
 
 =cut
 
